@@ -1,4 +1,5 @@
-from typing import List
+import json
+from typing import Dict, List
 
 
 def dump_papers(papers: List[dict], filepath: str) -> None:
@@ -13,7 +14,7 @@ def dump_papers(papers: List[dict], filepath: str) -> None:
 
     with open(filepath, "w") as f:
         for paper in papers:
-            f.write(str(paper) + "\n")
+            f.write(json.dumps(paper) + "\n")
 
 
 def get_filename_from_query(query: List[str]) -> str:
@@ -28,3 +29,19 @@ def get_filename_from_query(query: List[str]) -> str:
     filename = "_".join([k if isinstance(k, str) else k[0] for k in query]) + ".jsonl"
     filename = filename.replace(" ", "").lower()
     return filename
+
+
+def load_jsonl(filepath: str) -> List[Dict[str, str]]:
+    """
+    Load data from a `.jsonl` file, i.e., a file with one dictionary per line
+
+    Args:
+        filepath (str): Path to `.jsonl` file.
+
+    Returns:
+        List[Dict[str, str]]: A list of dictionaries, one per paper.
+    """
+
+    with open(filepath, "r") as f:
+        data = [json.loads(line) for line in f.readlines()]
+    return data
